/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SIGBATTLE_ARENA
#define SIGBATTLE_ARENA

// Sigbattle includes
#include "Global.h"
#include "Team.h"
#include "TeamMember.h"

// Qt includes
#include <QtCore/QList>
#include <QtCore/QObject>
#include <QtCore/QPair>
#include <QtCore/QSet>
#include <QtCore/QUuid>

// Forward declarations
namespace Kross
{
class Action;
class ActionCollection;
}
namespace Sigmod
{
class Script;
}
namespace Sigscript
{
class SigmodWrapper;
}

namespace Sigbattle
{
class Player;

class SIGBATTLE_EXPORT Arena : public Sigscript::Config
{
    Q_OBJECT
    
    public:
        ~Arena();
        
        QList<TeamMember*> active() const;
        int numActiveTeams() const;
        
        Sigscript::SigmodWrapper* sigmod() const;
    signals:
        void battleStart();
        void battleEnd();
    public slots:
        void registerScript(const Sigmod::Script& script);
    protected slots:
        virtual void cleanUp();
    protected:
        Arena(Sigscript::SigmodWrapper* sigmod, QList<Player*> players, const bool isWild, QObject* parent);
        
        virtual void handleAction(TeamMember* teamMember, TeamMember::Action action);
        
        virtual void setupBattle();
        
        TeamMember* findMember(const QUuid& id);
        
        Sigscript::SigmodWrapper* m_sigmod;
        const bool m_isWild;
        QList<Player*> m_players;
        Kross::ActionCollection* m_actions;
    private:
        const QUuid m_id;
};

TeamMember::RequestedAction requestDecision(TeamMember* teamMember);
TeamMember::Action decision(TeamMember* teamMember);

}
Q_DECLARE_METATYPE(Sigbattle::Arena*)

#endif
