/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "Containment.h"

// Sigbattle includes
#include "TeamMember.h"

// Sigscript includes
#include "../sigscript/RulesWrapper.h"
#include "../sigscript/SigmodWrapper.h"

Sigbattle::Containment::Containment(Sigscript::SigmodWrapper* sigmod, QObject* parent) :
        QObject(parent),
        m_sigmod(sigmod)
{
}

QList<Sigbattle::TeamMember*> Sigbattle::Containment::members() const
{
    return m_members;
}

bool Sigbattle::Containment::addMember(TeamMember* member)
{
    if (m_members.size() < sigmod()->rules()->maxParty())
    {
        m_members.append(member);
//         member->reparent(this);
        return true;
    }
    return false;
}

Sigbattle::TeamMember* Sigbattle::Containment::findMember(const QUuid& id) const
{
    foreach (TeamMember* member, m_members)
    {
        if (member->id() == id)
            return member;
    }
    return NULL;
}

Sigscript::SigmodWrapper* Sigbattle::Containment::sigmod() const
{
    return m_sigmod;
}
