/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "Player.h"

// Sigmod includes
#include "../sigscript/RulesWrapper.h"
#include "../sigscript/SigmodWrapper.h"

Sigbattle::Player::Player(Sigscript::SigmodWrapper* sigmod, QObject* parent) :
        Team(sigmod, parent),
        m_arena(NULL),
        m_money(0)
{
}

void Sigbattle::Player::enterArena(Arena* arena)
{
    m_arena = arena;
    for (int i = 0; (m_active.size() < sigmod()->rules()->maxFight()) && (i < m_members.size()); ++i)
    {
        if (m_members[i]->currentHp())
            m_active.append(m_members[i]);
    }
    foreach (TeamMember* member, m_active)
        member->makeActive(arena);
}

QList<Sigbattle::TeamMember*> Sigbattle::Player::active()
{
    return m_active;
}

void Sigbattle::Player::switchOut(TeamMember* oldActive, TeamMember* newActive)
{
    oldActive->leaveArena();
    newActive->makeActive(m_arena);
    m_active.removeAll(oldActive);
    m_active.append(newActive);
}

int Sigbattle::Player::money() const
{
    return m_money;
}

void Sigbattle::Player::exitArena()
{
    foreach (TeamMember* member, m_active)
        member->leaveArena();
    m_active.clear();
    m_arena = NULL;
}

void Sigbattle::Player::giveMoney(const int amount)
{
    m_money += amount;
    if (sigmod()->rules()->maxMoney() < m_money)
        m_money = sigmod()->rules()->maxMoney();
}

void Sigbattle::Player::takeMoney(const int amount)
{
    m_money -= amount;
    if (m_money < 0)
        m_money = 0;
}
