/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "Author.h"

// Sigmod includes
#include "Macros.h"
#include "Sigmod.h"

// Qt includes
#include <QtCore/QRegExp>

Sigmod::Author::Author(const Author& author) :
        Object(author.parent(), author.id())
{
    *this = author;
}

Sigmod::Author::Author(const Sigmod* parent, const int id) :
        Object(parent, id),
        m_name(""),
        m_email(""),
        m_role("")
{
}

Sigmod::Author::Author(const Author& author, const Sigmod* parent, const int id) :
        Object(parent, id)
{
    *this = author;
}

Sigmod::Author::Author(const QDomElement& xml, const Sigmod* parent, const int id) :
        Object(parent, id)
{
    LOAD_ID();
    load(xml);
}

void Sigmod::Author::validate()
{
    TEST_BEGIN();
    if (m_name.isEmpty())
        emit(error("Name is empty"));
    if (m_email.isEmpty())
        emit(warning("Email is empty"));
    else if (!QRegExp("[a-zA-Z0-9%-_\\.]+@[a-zA-Z0-9\\-]+(\\.[a-zA-Z]+)*\\.[a-zA-Z]{2,4}").exactMatch(m_email))
        emit(error("Email is invalid"));
    if (m_role.isEmpty())
        emit(error("Role is empty"));
    TEST_END();
}

void Sigmod::Author::load(const QDomElement& xml)
{
    LOAD_BEGIN();
    LOAD(name);
    LOAD(email);
    LOAD(role);
}

QDomElement Sigmod::Author::save() const
{
    SAVE_CREATE();
    SAVE(name);
    SAVE(email);
    SAVE(role);
    return xml;
}

void Sigmod::Author::setName(const QString& name)
{
    CHECK(name);
}

void Sigmod::Author::setEmail(const QString& email)
{
    CHECK(email);
}

void Sigmod::Author::setRole(const QString& role)
{
    CHECK(role);
}

QString Sigmod::Author::name() const
{
    return m_name;
}

QString Sigmod::Author::email() const
{
    return m_email;
}

QString Sigmod::Author::role() const
{
    return m_role;
}

Sigmod::Author& Sigmod::Author::operator=(const Author& rhs)
{
    if (this == &rhs)
        return *this;
    COPY(name);
    COPY(email);
    COPY(role);
    return *this;
}
