/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SIGMOD_BADGE
#define SIGMOD_BADGE

// Sigmod includes
#include "Fraction.h"
#include "Object.h"

namespace Sigmod
{
// Forward declarations
class Sigmod;

class SIGMOD_EXPORT Badge : public Object
{
    Q_OBJECT
    
    public:
        Badge(const Badge& badge);
        Badge(const Sigmod* parent, const int id);
        Badge(const Badge& badge, const Sigmod* parent, const int id);
        Badge(const QDomElement& xml, const Sigmod* parent, const int id = -1);
        
        void validate();
        
        void load(const QDomElement& xml);
        QDomElement save() const;
        
        void setName(const QString& name);
        void setFace(const int face);
        void setBadge(const int badge);
        void setObey(const int obey);
        void setStat(const Stat stat, const Fraction& multiplier);
        
        QString name() const;
        int face() const;
        int badge() const;
        int obey() const;
        Fraction stat(const Stat stat) const;
        
        Badge& operator=(const Badge& rhs);
    private:
        void setStat(const Fraction& multiplier);
        
        QString m_name;
        int m_face;
        int m_badge;
        int m_obey;
        QVarLengthArray<Fraction, ST_End_GSC - ST_No_HP_Start> m_stat;
};
}

#endif
