/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "CoinListObject.h"

// Sigmod includes
#include "CoinList.h"
#include "Macros.h"
#include "Sigmod.h"

const QStringList Sigmod::CoinListObject::TypeStr = QStringList() << "Item" << "Team Member";

Sigmod::CoinListObject::CoinListObject(const CoinListObject& object) :
        Object(object.parent(), object.id())
{
    *this = object;
}

Sigmod::CoinListObject::CoinListObject(const CoinList* parent, const int id) :
        Object(parent, id),
        m_type(Item),
        m_object(INT_MAX),
        m_amount(1),
        m_cost(0)
{
}

Sigmod::CoinListObject::CoinListObject(const CoinListObject& object, const CoinList* parent, const int id) :
        Object(parent, id)
{
    *this = object;
}

Sigmod::CoinListObject::CoinListObject(const QDomElement& xml, const CoinList* parent, const int id) :
        Object(parent, id)
{
    LOAD_ID();
    load(xml);
}

void Sigmod::CoinListObject::validate()
{
    TEST_BEGIN();
    TEST(setObject, object);
    TEST(setAmount, amount);
    TEST_END();
}

void Sigmod::CoinListObject::load(const QDomElement& xml)
{
    LOAD_BEGIN();
    LOAD(type);
    LOAD(object);
    LOAD(amount);
    LOAD(cost);
}

QDomElement Sigmod::CoinListObject::save() const
{
    SAVE_CREATE();
    SAVE(type);
    SAVE(object);
    SAVE(amount);
    SAVE(cost);
    return xml;
}

void Sigmod::CoinListObject::setType(const Type type)
{
    CHECK(type);
}

void Sigmod::CoinListObject::setObject(const int object)
{
    if (((Item == m_type) && (qobject_cast<const Sigmod*>(sigmod())->itemIndex(object) == INT_MAX)) || ((Species == m_type) && (qobject_cast<const Sigmod*>(sigmod())->speciesIndex(object) == INT_MAX)))
        emit(error(bounds("object")));
    else
        CHECK(object);
}

void Sigmod::CoinListObject::setAmount(const int amount)
{
    if (!amount || ((Species == m_type) && (1 < amount)))
        emit(error(bounds("amount")));
    else
        CHECK(amount);
}

void Sigmod::CoinListObject::setCost(const int cost)
{
    CHECK(cost);
}

Sigmod::CoinListObject::Type Sigmod::CoinListObject::type() const
{
    return m_type;
}

int Sigmod::CoinListObject::object() const
{
    return m_object;
}

int Sigmod::CoinListObject::amount() const
{
    return m_amount;
}

int Sigmod::CoinListObject::cost() const
{
    return m_cost;
}

Sigmod::CoinListObject& Sigmod::CoinListObject::operator=(const CoinListObject& rhs)
{
    if (this == &rhs)
        return *this;
    COPY(type);
    COPY(object);
    COPY(amount);
    COPY(cost);
    return *this;
}
