/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SIGMOD_COINLISTOBJECT
#define SIGMOD_COINLISTOBJECT

// Sigmod includes
#include "Object.h"

namespace Sigmod
{
// Forward declarations
class CoinList;

class SIGMOD_EXPORT CoinListObject : public Object
{
    Q_OBJECT
    Q_ENUMS(Type)
    
    public:
        enum Type
        {
            Item = 0,
            Species = 1
        };
        static const QStringList TypeStr;
        
        CoinListObject(const CoinListObject& object);
        CoinListObject(const CoinList* parent, const int id);
        CoinListObject(const CoinListObject& object, const CoinList* parent, const int id);
        CoinListObject(const QDomElement& xml, const CoinList* parent, const int id = -1);
        
        void validate();
        
        void load(const QDomElement& xml);
        QDomElement save() const;
        
        void setType(const Type type);
        void setObject(const int object);
        void setAmount(const int amount);
        void setCost(const int cost);
        
        Type type() const;
        int object() const;
        int amount() const;
        int cost() const;
        
        CoinListObject& operator=(const CoinListObject& rhs);
    private:
        Type m_type;
        int m_object;
        int m_amount;
        int m_cost;
};
}
Q_DECLARE_METATYPE(Sigmod::CoinListObject::Type)

#endif
