/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "EggGroup.h"

// Sigmod includes
#include "Macros.h"
#include "Sigmod.h"

Sigmod::EggGroup::EggGroup(const EggGroup& eggGroup) :
        Object(eggGroup.parent(), eggGroup.id())
{
    *this = eggGroup;
}

Sigmod::EggGroup::EggGroup(const Sigmod* parent, const int id) :
        Object(parent, id),
        m_name("")
{
}

Sigmod::EggGroup::EggGroup(const EggGroup& eggGroup, const Sigmod* parent, const int id) :
        Object(parent, id)
{
    *this = eggGroup;
}

Sigmod::EggGroup::EggGroup(const QDomElement& xml, const Sigmod* parent, const int id) :
        Object(parent, id)
{
    LOAD_ID();
    load(xml);
}

void Sigmod::EggGroup::validate()
{
    TEST_BEGIN();
    if (m_name.isEmpty())
        emit(error("Name is empty"));
    TEST_END();
}

void Sigmod::EggGroup::load(const QDomElement& xml)
{
    LOAD_BEGIN();
    LOAD(name);
}

QDomElement Sigmod::EggGroup::save() const
{
    SAVE_CREATE();
    SAVE(name);
    return xml;
}

void Sigmod::EggGroup::setName(const QString& name)
{
    CHECK(name);
}

QString Sigmod::EggGroup::name() const
{
    return m_name;
}

Sigmod::EggGroup& Sigmod::EggGroup::operator=(const EggGroup& rhs)
{
    if (this == &rhs)
        return *this;
    COPY(name);
    return *this;
}
