/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SIGMOD_ITEMTYPE
#define SIGMOD_ITEMTYPE

// Sigmod includes
#include "Object.h"

namespace Sigmod
{
// Forward declarations
class Sigmod;

class SIGMOD_EXPORT ItemType : public Object
{
    Q_OBJECT
    Q_ENUMS(Count)
    
    public:
        enum Count
        {
            Distinct = 0,
            Total = 1
        };
        static QStringList CountStr;
        
        ItemType(const ItemType& itemType);
        ItemType(const Sigmod* parent, const int id);
        ItemType(const ItemType& itemType, const Sigmod* parent, const int id);
        ItemType(const QDomElement& xml, const Sigmod* parent, const int id = -1);
        
        void validate();
        
        void load(const QDomElement& xml);
        QDomElement save() const;
        
        void setName(const QString& name);
        void setComputer(const int computer);
        void setPlayer(const int player);
        void setCount(const Count count);
        
        QString name() const;
        int computer() const;
        int player() const;
        Count count() const;
        
        ItemType& operator=(const ItemType& rhs);
    private:
        QString m_name;
        int m_computer;
        int m_player;
        Count m_count;
};
}
Q_DECLARE_METATYPE(Sigmod::ItemType::Count)

#endif
