/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "Nature.h"

// Sigmod includes
#include "Macros.h"
#include "Rules.h"
#include "Sigmod.h"

Sigmod::Nature::Nature(const Nature& nature) :
        Object(nature.parent(), nature.id()),
        m_stat(ST_End_GSC - ST_No_HP_Start)
{
    *this = nature;
}

Sigmod::Nature::Nature(const Sigmod* parent, const int id) :
        Object(parent, id),
        m_name(""),
        m_stat(ST_End_GSC - ST_No_HP_Start),
        m_weight(1)
{
    for (int i = 0; i < m_stat.size(); ++i)
        m_stat[i].set(1, 1);
}

Sigmod::Nature::Nature(const Nature& nature, const Sigmod* parent, const int id) :
        Object(parent, id),
        m_stat(ST_End_GSC - ST_No_HP_Start)
{
    *this = nature;
}

Sigmod::Nature::Nature(const QDomElement& xml, const Sigmod* parent, const int id) :
        Object(parent, id),
        m_stat(ST_End_GSC - ST_No_HP_Start)
{
    LOAD_ID();
    load(xml);
}

void Sigmod::Nature::validate()
{
    TEST_BEGIN();
    if (m_name.isEmpty())
        emit(error("Name is empty"));
    TEST(setWeight, weight);
    TEST_END();
}

void Sigmod::Nature::load(const QDomElement& xml)
{
    LOAD_BEGIN();
    LOAD(name);
    LOAD_ARRAY(stat);
    LOAD(weight);
}

QDomElement Sigmod::Nature::save() const
{
    SAVE_CREATE();
    SAVE(name);
    SAVE_ARRAY(stat);
    SAVE(weight);
    return xml;
}

void Sigmod::Nature::setName(const QString& name)
{
    CHECK(name);
}

void Sigmod::Nature::setStat(const Stat stat, const Fraction& multiplier)
{
    switch (stat)
    {
        case ST_SpecialDefense:
            if (qobject_cast<const Sigmod*>(sigmod())->rules()->specialSplit())
        case ST_Attack ... ST_Special:
            break;
        default:
            emit(warning(bounds("stat")));
            return;
    }
    CHECK_ARRAY(stat[stat - ST_No_HP_Start], multiplier);
}

void Sigmod::Nature::setWeight(const int weight)
{
    if (!weight)
        emit(error(bounds("weight")));
    else
        CHECK(weight);
}

QString Sigmod::Nature::name() const
{
    return m_name;
}

Sigmod::Fraction Sigmod::Nature::stat(const Stat stat) const
{
    switch (stat)
    {
        case ST_SpecialDefense:
            if (qobject_cast<const Sigmod*>(sigmod())->rules()->specialSplit())
        case ST_Attack ... ST_Special:
            return m_stat[stat - ST_No_HP_Start];
        default:
            emit(warning(bounds("stat")));
            return Fraction();
    }
}

int Sigmod::Nature::weight() const
{
    return m_weight;
}

Sigmod::Nature& Sigmod::Nature::operator=(const Nature& rhs)
{
    if (this == &rhs)
        return *this;
    COPY(name);
    COPY(stat);
    COPY(weight);
    return *this;
}
