/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "Skin.h"

// Sigmod includes
#include "Macros.h"
#include "Sigmod.h"
#include "Script.h"

Sigmod::Skin::Skin(const Skin& skin) :
        Object(skin.parent(), skin.id())
{
    *this = skin;
}

Sigmod::Skin::Skin(const Sigmod* parent, const int id) :
        Object(parent, id),
        m_name(""),
        m_script("", "")
{
}

Sigmod::Skin::Skin(const Skin& skin, const Sigmod* parent, const int id) :
        Object(parent, id)
{
    *this = skin;
}

Sigmod::Skin::Skin(const QDomElement& xml, const Sigmod* parent, const int id) :
        Object(parent, id)
{
    LOAD_ID();
    load(xml);
}

void Sigmod::Skin::validate()
{
    TEST_BEGIN();
    if (m_name.isEmpty())
        emit(error("Name is empty"));
    TEST_END();
}

void Sigmod::Skin::load(const QDomElement& xml)
{
    LOAD_BEGIN();
    LOAD(name);
    LOAD(script);
}

QDomElement Sigmod::Skin::save() const
{
    SAVE_CREATE();
    SAVE(name);
    SAVE(script);
    return xml;
}

void Sigmod::Skin::setName(const QString& name)
{
    CHECK(name);
}

void Sigmod::Skin::setScript(const Script& script)
{
    CHECK(script);
}

QString Sigmod::Skin::name() const
{
    return m_name;
}

Sigmod::Script Sigmod::Skin::script() const
{
    return m_script;
}

Sigmod::Skin& Sigmod::Skin::operator=(const Skin& rhs)
{
    if (this == &rhs)
        return *this;
    COPY(name);
    COPY(script);
    return *this;
}
