/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "Sound.h"

// Sigmod includes
#include "Macros.h"
#include "Sigmod.h"

const QStringList Sigmod::Sound::TypeStr = QStringList() << "Sound Effect" << "Music";

Sigmod::Sound::Sound(const Sound& sound) :
        Object(sound.parent(), sound.id())
{
    *this = sound;
}

Sigmod::Sound::Sound(const Sigmod* parent, const int id) :
        Object(parent, id),
        m_name(""),
        m_type(SoundEffect),
        m_data()
{
}

Sigmod::Sound::Sound(const Sound& sound, const Sigmod* parent, const int id) :
        Object(parent, id)
{
    *this = sound;
}

Sigmod::Sound::Sound(const QDomElement& xml, const Sigmod* parent, const int id) :
        Object(parent, id)
{
    LOAD_ID();
    load(xml);
}

void Sigmod::Sound::validate()
{
    TEST_BEGIN();
    if (m_name.isEmpty())
        emit(error("Name is empty"));
    if (m_data.isEmpty())
        emit(error("Data is empty"));
    TEST_END();
}

void Sigmod::Sound::load(const QDomElement& xml)
{
    LOAD_BEGIN();
    LOAD(name);
    LOAD(type);
    LOAD(data);
}

QDomElement Sigmod::Sound::save() const
{
    SAVE_CREATE();
    SAVE(name);
    SAVE(type);
    SAVE(data);
    return xml;
}

void Sigmod::Sound::setName(const QString& name)
{
    CHECK(name);
}

void Sigmod::Sound::setType(const Type type)
{
    CHECK(type);
}

void Sigmod::Sound::setData(const QByteArray& data)
{
    CHECK(data);
}

QString Sigmod::Sound::name() const
{
    return m_name;
}

Sigmod::Sound::Type Sigmod::Sound::type() const
{
    return m_type;
}

QByteArray Sigmod::Sound::data() const
{
    return m_data;
}

Sigmod::Sound& Sigmod::Sound::operator=(const Sound& rhs)
{
    if (this == &rhs)
        return *this;
    clear();
    COPY(name);
    COPY(type);
    COPY(data);
    return *this;
}
