/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "Status.h"

// Sigmod includes
#include "Macros.h"
#include "Sigmod.h"
#include "Script.h"

Sigmod::Status::Status(const Status& status) :
        Object(status.parent(), status.id())
{
    *this = status;
}

Sigmod::Status::Status(const Sigmod* parent, const int id) :
        Object(parent, id),
        m_name(""),
        m_battleScript("", ""),
        m_worldScript("", "")
{
}

Sigmod::Status::Status(const Status& status, const Sigmod* parent, const int id) :
        Object(parent, id)
{
    *this = status;
}

Sigmod::Status::Status(const QDomElement& xml, const Sigmod* parent, const int id) :
        Object(parent, id)
{
    LOAD_ID();
    load(xml);
}

Sigmod::Status::~Status()
{
}

void Sigmod::Status::validate()
{
    TEST_BEGIN();
    if (m_name.isEmpty())
        emit(error("Name is empty"));
    TEST_END();
}

void Sigmod::Status::load(const QDomElement& xml)
{
    LOAD_BEGIN();
    LOAD(name);
    LOAD(battleScript);
    LOAD(worldScript);
}

QDomElement Sigmod::Status::save() const
{
    SAVE_CREATE();
    SAVE(name);
    SAVE(battleScript);
    SAVE(worldScript);
    return xml;
}

void Sigmod::Status::setName(const QString& name)
{
    CHECK(name);
}

void Sigmod::Status::setBattleScript(const Script& battleScript)
{
    CHECK(battleScript);
}

void Sigmod::Status::setWorldScript(const Script& worldScript)
{
    CHECK(worldScript);
}

QString Sigmod::Status::name() const
{
    return m_name;
}

Sigmod::Script Sigmod::Status::battleScript() const
{
    return m_battleScript;
}

Sigmod::Script Sigmod::Status::worldScript() const
{
    return m_worldScript;
}

Sigmod::Status& Sigmod::Status::operator=(const Status& rhs)
{
    if (this == &rhs)
        return *this;
    COPY(name);
    COPY(battleScript);
    COPY(worldScript);
    return *this;
}
