/*
 * Copyright 2007-2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SIGMOD_TILE
#define SIGMOD_TILE

// Sigmod includes
#include "Object.h"
#include "Script.h"

namespace Sigmod
{
// Forward declarations
class Sigmod;

class SIGMOD_EXPORT Tile : public Object
{
    Q_OBJECT
    
    public:
        Tile(const Tile& tile);
        Tile(const Sigmod* parent, const int id);
        Tile(const Tile& tile, const Sigmod* parent, const int id);
        Tile(const QDomElement& xml, const Sigmod* parent, const int id = -1);
        
        void validate();
        
        void load(const QDomElement& xml);
        QDomElement save() const;
        
        void setName(const QString& name);
        void setSprite(const int sprite);
        void setFrom(const Direction direction, const bool state);
        void setScript(const Script& script);
        
        QString name() const;
        int sprite() const;
        bool from(const Direction direction) const;
        Script script() const;
        
        Tile& operator=(const Tile& rhs);
    private:
        QString m_name;
        int m_sprite;
        QVarLengthArray<bool, D_End> m_from;
        Script m_script;
};
}

#endif
