/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "BadgeUI.h"

// Sigmod includes
#include "../sigmod/Badge.h"
#include "../sigmod/Rules.h"
#include "../sigmod/Sigmod.h"
#include "../sigmod/Sprite.h"

Sigmodr::BadgeUI::BadgeUI(Sigmod::Badge* badge, QWidget* parent) :
        ObjectUI(parent)
{
    setupUi(this);
    setObjects(badge, new Sigmod::Badge(*badge));
}

Sigmodr::BadgeUI::~BadgeUI()
{
}

void Sigmodr::BadgeUI::initGui()
{
    connect(varStat, SIGNAL(activated(const int)), this, SLOT(setGui()));
}

void Sigmodr::BadgeUI::refreshGui()
{
    varObey->setMaximum(sigmod()->rules()->maxLevel());
    varFace->clear();
    varBadge->clear();
    for (int i = 0; i < sigmod()->spriteCount(); ++i)
    {
        const Sigmod::Sprite* sprite = sigmod()->sprite(i);
        varFace->addItem(QPixmap::fromImage(sprite->sprite()), sprite->name(), sprite->id());
        varBadge->addItem(QPixmap::fromImage(sprite->sprite()), sprite->name(), sprite->id());
    }
    varStat->clear();
    const bool isSplit = sigmod()->rules()->specialSplit();
    const QStringList& statNames = (isSplit ? Sigmod::StatGSCStr : Sigmod::StatRBYStr);
    varStat->addItem(statNames[Sigmod::ST_Attack], QVariant::fromValue(Sigmod::ST_Attack));
    varStat->addItem(statNames[Sigmod::ST_Defense], QVariant::fromValue(Sigmod::ST_Defense));
    varStat->addItem(statNames[Sigmod::ST_Speed], QVariant::fromValue(Sigmod::ST_Speed));
    if (isSplit)
    {
        varStat->addItem(statNames[Sigmod::ST_SpecialAttack], QVariant::fromValue(Sigmod::ST_SpecialAttack));
        varStat->addItem(statNames[Sigmod::ST_SpecialDefense], QVariant::fromValue(Sigmod::ST_SpecialDefense));
    }
    else
        varStat->addItem(statNames[Sigmod::ST_Special], QVariant::fromValue(Sigmod::ST_Special));
}

void Sigmodr::BadgeUI::setGui()
{
    varName->setText(qobject_cast<Sigmod::Badge*>(modified())->name());
    varObey->setValue(qobject_cast<Sigmod::Badge*>(modified())->obey());
    varFace->setCurrentIndex(varFace->findData(qobject_cast<Sigmod::Badge*>(modified())->face()));
    varBadge->setCurrentIndex(varBadge->findData(qobject_cast<Sigmod::Badge*>(modified())->badge()));
    Sigmod::Stat stat = varStat->itemData(varStat->currentIndex()).value<Sigmod::Stat>();
    Sigmod::Fraction multiplier = qobject_cast<Sigmod::Badge*>(modified())->stat(stat);
    varStatMultiplier->setValue(qobject_cast<Sigmod::Badge*>(modified())->stat(varStat->itemData(varStat->currentIndex()).value<Sigmod::Stat>()));
}

void Sigmodr::BadgeUI::apply()
{
    *qobject_cast<Sigmod::Badge*>(original()) = *qobject_cast<Sigmod::Badge*>(modified());
    emit(changed(false));
}

void Sigmodr::BadgeUI::discard()
{
    *qobject_cast<Sigmod::Badge*>(modified()) = *qobject_cast<Sigmod::Badge*>(original());
    setGui();
    emit(changed(false));
}

void Sigmodr::BadgeUI::on_varName_textChanged(const QString& name)
{
    const int cursor = varName->cursorPosition();
    qobject_cast<Sigmod::Badge*>(modified())->setName(name);
    varName->setCursorPosition(cursor);
}

void Sigmodr::BadgeUI::on_varObey_valueChanged(const int obey)
{
    qobject_cast<Sigmod::Badge*>(modified())->setObey(obey);
}

void Sigmodr::BadgeUI::on_varFace_currentIndexChanged(const int face)
{
    qobject_cast<Sigmod::Badge*>(modified())->setFace(varFace->itemData(face).toInt());
}

void Sigmodr::BadgeUI::on_varBadge_currentIndexChanged(const int badge)
{
    qobject_cast<Sigmod::Badge*>(modified())->setBadge(varFace->itemData(badge).toInt());
}

void Sigmodr::BadgeUI::on_varStatMultiplier_valueChanged(const Sigmod::Fraction& multiplier)
{
    qobject_cast<Sigmod::Badge*>(modified())->setStat(varStat->itemData(varStat->currentIndex()).value<Sigmod::Stat>(), multiplier);
}
