/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "ItemTypeUI.h"

// Sigmod includes
#include "../sigmod/ItemType.h"

Sigmodr::ItemTypeUI::ItemTypeUI(Sigmod::ItemType* itemType, QWidget* parent) :
        ObjectUI(parent)
{
    setupUi(this);
    setObjects(itemType, new Sigmod::ItemType(*itemType));
}

Sigmodr::ItemTypeUI::~ItemTypeUI()
{
}

void Sigmodr::ItemTypeUI::initGui()
{
    varCount->addItem(Sigmod::ItemType::CountStr[Sigmod::ItemType::Distinct], QVariant::fromValue(Sigmod::ItemType::Distinct));
    varCount->addItem(Sigmod::ItemType::CountStr[Sigmod::ItemType::Total], QVariant::fromValue(Sigmod::ItemType::Total));
}

void Sigmodr::ItemTypeUI::setGui()
{
    varName->setText(qobject_cast<Sigmod::ItemType*>(modified())->name());
    varComputer->setValue(qobject_cast<Sigmod::ItemType*>(modified())->computer());
    varPlayer->setValue(qobject_cast<Sigmod::ItemType*>(modified())->player());
    varCount->setCurrentIndex(qobject_cast<Sigmod::ItemType*>(modified())->count());
}

void Sigmodr::ItemTypeUI::apply()
{
    *qobject_cast<Sigmod::ItemType*>(original()) = *qobject_cast<Sigmod::ItemType*>(modified());
    emit(changed(false));
}

void Sigmodr::ItemTypeUI::discard()
{
    *qobject_cast<Sigmod::ItemType*>(modified()) = *qobject_cast<Sigmod::ItemType*>(original());
    setGui();
    emit(changed(false));
}

void Sigmodr::ItemTypeUI::on_varName_textChanged(const QString& name)
{
    const int cursor = varName->cursorPosition();
    qobject_cast<Sigmod::ItemType*>(modified())->setName(name);
    varName->setCursorPosition(cursor);
}

void Sigmodr::ItemTypeUI::on_varComputer_valueChanged(const int computer)
{
    qobject_cast<Sigmod::ItemType*>(modified())->setComputer(computer);
}

void Sigmodr::ItemTypeUI::on_varPlayer_valueChanged(const int player)
{
    qobject_cast<Sigmod::ItemType*>(modified())->setPlayer(player);
}

void Sigmodr::ItemTypeUI::on_varCount_currentIndexChanged(const int count)
{
    qobject_cast<Sigmod::ItemType*>(modified())->setCount(varCount->itemData(count).value<Sigmod::ItemType::Count>());
}
