/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "MapWildListEncounterUI.h"

// Sigmod includes
#include "../sigmod/MapWildListEncounter.h"
#include "../sigmod/Rules.h"
#include "../sigmod/Sigmod.h"
#include "../sigmod/Species.h"

Sigmodr::MapWildListEncounterUI::MapWildListEncounterUI(Sigmod::MapWildListEncounter* encounter, QWidget* parent) :
        ObjectUI(parent)
{
    setupUi(this);
    setObjects(encounter, new Sigmod::MapWildListEncounter(*encounter));
}

Sigmodr::MapWildListEncounterUI::~MapWildListEncounterUI()
{
}

void Sigmodr::MapWildListEncounterUI::refreshGui()
{
    varSpecies->clear();
    for (int i = 0; i < sigmod()->speciesCount(); ++i)
    {
        const Sigmod::Species* species = sigmod()->species(i);
        varSpecies->addItem(species->name(), species->id());
    }
    varLevel->setMaximum(sigmod()->rules()->maxLevel());
}

void Sigmodr::MapWildListEncounterUI::setGui()
{
    varSpecies->setCurrentIndex(varSpecies->findData(qobject_cast<Sigmod::MapWildListEncounter*>(modified())->species()));
    varLevel->setValue(qobject_cast<Sigmod::MapWildListEncounter*>(modified())->level());
    varWeight->setValue(qobject_cast<Sigmod::MapWildListEncounter*>(modified())->weight());
}

void Sigmodr::MapWildListEncounterUI::apply()
{
    *qobject_cast<Sigmod::MapWildListEncounter*>(original()) = *qobject_cast<Sigmod::MapWildListEncounter*>(modified());
    emit(changed(false));
}

void Sigmodr::MapWildListEncounterUI::discard()
{
    *qobject_cast<Sigmod::MapWildListEncounter*>(modified()) = *qobject_cast<Sigmod::MapWildListEncounter*>(original());
    setGui();
    emit(changed(false));
}

void Sigmodr::MapWildListEncounterUI::on_varSpecies_activated(const int species)
{
    qobject_cast<Sigmod::MapWildListEncounter*>(modified())->setSpecies(varSpecies->itemData(species).toInt());
}

void Sigmodr::MapWildListEncounterUI::on_varLevel_valueChanged(const int level)
{
    qobject_cast<Sigmod::MapWildListEncounter*>(modified())->setLevel(level);
}

void Sigmodr::MapWildListEncounterUI::on_varWeight_valueChanged(const int weight)
{
    qobject_cast<Sigmod::MapWildListEncounter*>(modified())->setWeight(weight);
}
