/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "MoveUI.h"

// Sigmod includes
#include "../sigmod/Move.h"
#include "../sigmod/Sigmod.h"
#include "../sigmod/Type.h"

Sigmodr::MoveUI::MoveUI(Sigmod::Move* move, QWidget* parent) :
        ObjectUI(parent)
{
    setupUi(this);
    setObjects(move, new Sigmod::Move(*move));
}

Sigmodr::MoveUI::~MoveUI()
{
}

void Sigmodr::MoveUI::refreshGui()
{
    varType->clear();
    for (int i = 0; i < sigmod()->typeCount(); ++i)
    {
        const Sigmod::Type* type = sigmod()->type(i);
        varType->addItem(type->name(), type->id());
    }
}

void Sigmodr::MoveUI::setGui()
{
    varName->setText(qobject_cast<Sigmod::Move*>(modified())->name());
    varPriority->setValue(qobject_cast<Sigmod::Move*>(modified())->priority());
    varAccuracy->setValue(qobject_cast<Sigmod::Move*>(modified())->accuracy());
    varPower->setValue(qobject_cast<Sigmod::Move*>(modified())->power());
    varType->setCurrentIndex(varType->findData(qobject_cast<Sigmod::Move*>(modified())->type()));
    varPowerPoints->setValue(qobject_cast<Sigmod::Move*>(modified())->powerPoints());
    varSpecial->setChecked(qobject_cast<Sigmod::Move*>(modified())->special() ? Qt::Checked : Qt::Unchecked);
    varDescription->setText(qobject_cast<Sigmod::Move*>(modified())->description());
    varBattleScript->setValue(qobject_cast<Sigmod::Move*>(modified())->battleScript());
    varWorldScript->setValue(qobject_cast<Sigmod::Move*>(modified())->worldScript());
    varPriorityScript->setValue(qobject_cast<Sigmod::Move*>(modified())->priorityScript());
}

void Sigmodr::MoveUI::apply()
{
    *qobject_cast<Sigmod::Move*>(original()) = *qobject_cast<Sigmod::Move*>(modified());
    emit(changed(false));
}

void Sigmodr::MoveUI::discard()
{
    *qobject_cast<Sigmod::Move*>(modified()) = *qobject_cast<Sigmod::Move*>(original());
    setGui();
    emit(changed(false));
}

void Sigmodr::MoveUI::on_varName_textChanged(const QString& name)
{
    const int cursor = varName->cursorPosition();
    qobject_cast<Sigmod::Move*>(modified())->setName(name);
    varName->setCursorPosition(cursor);
}

void Sigmodr::MoveUI::on_varPriority_valueChanged(const int priority)
{
    qobject_cast<Sigmod::Move*>(modified())->setPriority(priority);
}

void Sigmodr::MoveUI::on_varAccuracy_valueChanged(const Sigmod::Fraction& accuracy)
{
    qobject_cast<Sigmod::Move*>(modified())->setAccuracy(accuracy);
}

void Sigmodr::MoveUI::on_varPower_valueChanged(const int power)
{
    qobject_cast<Sigmod::Move*>(modified())->setPower(power);
}

void Sigmodr::MoveUI::on_varType_activated(const int type)
{
    qobject_cast<Sigmod::Move*>(modified())->setType(varType->itemData(type).toInt());
}

void Sigmodr::MoveUI::on_varPowerPoints_valueChanged(const int powerPoints)
{
    qobject_cast<Sigmod::Move*>(modified())->setPowerPoints(powerPoints);
}

void Sigmodr::MoveUI::on_varSpecial_toggled(const bool special)
{
    qobject_cast<Sigmod::Move*>(modified())->setSpecial(special);
}

void Sigmodr::MoveUI::on_varDescription_textChanged(const QString& description)
{
    const int cursor = varDescription->cursorPosition();
    qobject_cast<Sigmod::Move*>(modified())->setDescription(description);
    varDescription->setCursorPosition(cursor);
}

void Sigmodr::MoveUI::on_varBattleScript_valueChanged(const Sigmod::Script& battleScript)
{
    qobject_cast<Sigmod::Move*>(modified())->setBattleScript(battleScript);
}

void Sigmodr::MoveUI::on_varWorldScript_valueChanged(const Sigmod::Script& worldScript)
{
    qobject_cast<Sigmod::Move*>(modified())->setWorldScript(worldScript);
}

void Sigmodr::MoveUI::on_varPriorityScript_valueChanged(const Sigmod::Script& priorityScript)
{
    qobject_cast<Sigmod::Move*>(modified())->setPriorityScript(priorityScript);
}
