/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SIGMODR_SIGMODTREE
#define SIGMODR_SIGMODTREE

// KDE includes
#include <KUrl>

// Qt includes
#include <QtCore/QMap>
#include <QtGui/QTreeView>
#include <QtXml/QDomDocument>

// Forward declarations
class KMenu;
namespace Sigmod
{
class Sigmod;
}

namespace Sigmodr
{
class ObjectUI;

class SigmodTree : public QTreeView
{
    Q_OBJECT
    
    public:
        SigmodTree(QWidget* parent = 0);
        
        QString description(const QModelIndex& index);
        Sigmodr::ObjectUI* editorWidget(const QModelIndex& index);
        KMenu* contextMenu(const QModelIndex& index);
        
        const Sigmod::Sigmod* currentSigmod() const;
        
        QDomDocument copy(const QModelIndex& index);
        void paste(const QModelIndex& index, const QDomDocument& data);
        
        QList<const Sigmod::Sigmod*> openedSigmods() const;
        void addSigmod(Sigmod::Sigmod* sigmod, const KUrl& url = KUrl());
        void deleteSigmod(const Sigmod::Sigmod* sigmod);
        void deleteAllSigmods();
        
        bool isOpen(const KUrl& url) const;
        
        KUrl url(const Sigmod::Sigmod* sigmod) const;
        QStringList urls() const;
        void setUrl(const Sigmod::Sigmod* sigmod, const KUrl& url);
        
        bool dirty(const Sigmod::Sigmod* sigmod) const;
        bool dirty() const;
    public slots:
        void setDirty(const Sigmod::Sigmod* sigmod, const bool dirty);
    private slots:
        void setDirty();
    private:
        typedef QPair<KUrl, bool> UrlDirty;
        
        QMap<const Sigmod::Sigmod*, UrlDirty> m_sigmods;
};
}

#endif
