/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SIGMODR_SIGMODTREEMODELMODEL
#define SIGMODR_SIGMODTREEMODELMODEL

// Model includes
#include "models/RootModel.h"

// Qt includes
#include <QtCore/QAbstractItemModel>
#include <QtCore/QModelIndex>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

namespace Sigmodr
{
class SigmodTreeModel : public QAbstractItemModel
{
    Q_OBJECT

    public:
        SigmodTreeModel(QObject* parent = 0);
        ~SigmodTreeModel();
        
        QVariant data(const QModelIndex& index, int role) const;
        QVariant headerData(int /*section*/, Qt::Orientation /*orientation*/, int /*role = Qt::DisplayRole*/) const;
        
        QModelIndex index(int row, int column, const QModelIndex& parent) const;
        QModelIndex parent(const QModelIndex& index) const;
        
        int rowCount(const QModelIndex& parent = QModelIndex()) const;
        int columnCount(const QModelIndex& /*parent = QModelIndex()*/) const;
        
        Qt::ItemFlags flags(const QModelIndex& index) const;
        bool setData(const QModelIndex& index, const QVariant& value, int role = Qt::EditRole);
        
        QStringList mimeTypes() const;
        QMimeData* mimeData(const QModelIndexList& indexes) const;
        bool dropMimeData(const QMimeData* data, Qt::DropAction action, int /*row*/, int /*column*/, const QModelIndex& parent);
        
        void addSigmod(Sigmod::Sigmod* sigmod);
        void deleteSigmod(const Sigmod::Sigmod* sigmod);
        const Sigmod::Sigmod* findSigmod(const QModelIndex& index) const;
    signals:
        void dirty(const Sigmod::Sigmod* sigmod, const bool dirty);
    protected slots:
        void rowsChanged(const QList<int>& rows);
    private:
        BaseModel* getItem(const QModelIndex& index) const;
        
        RootModel* m_root;
};
}

#endif
