/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "SkinUI.h"

// Sigmod includes
#include "../sigmod/Skin.h"

Sigmodr::SkinUI::SkinUI(Sigmod::Skin* skin, QWidget* parent) :
        ObjectUI(parent)
{
    setupUi(this);
    setObjects(skin, new Sigmod::Skin(*skin));
}

Sigmodr::SkinUI::~SkinUI()
{
}

void Sigmodr::SkinUI::setGui()
{
    varName->setText(qobject_cast<Sigmod::Skin*>(modified())->name());
    varScript->setValue(qobject_cast<Sigmod::Skin*>(modified())->script());
}

void Sigmodr::SkinUI::apply()
{
    *qobject_cast<Sigmod::Skin*>(original()) = *qobject_cast<Sigmod::Skin*>(modified());
    emit(changed(false));
}

void Sigmodr::SkinUI::discard()
{
    *qobject_cast<Sigmod::Skin*>(modified()) = *qobject_cast<Sigmod::Skin*>(original());
    setGui();
    emit(changed(false));
}

void Sigmodr::SkinUI::on_varName_textChanged(const QString& name)
{
    const int cursor = varName->cursorPosition();
    qobject_cast<Sigmod::Skin*>(modified())->setName(name);
    varName->setCursorPosition(cursor);
}

void Sigmodr::SkinUI::on_varScript_valueChanged(const Sigmod::Script& script)
{
    qobject_cast<Sigmod::Skin*>(modified())->setScript(script);
}
