/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "TimeUI.h"

// Sigmod includes
#include "../sigmod/Time.h"

Sigmodr::TimeUI::TimeUI(Sigmod::Time* time, QWidget* parent) :
        ObjectUI(parent)
{
    setupUi(this);
    setObjects(time, new Sigmod::Time(*time));
}

Sigmodr::TimeUI::~TimeUI()
{
}

void Sigmodr::TimeUI::setGui()
{
    varName->setText(qobject_cast<Sigmod::Time*>(modified())->name());
    varTime->setTime(QTime(qobject_cast<Sigmod::Time*>(modified())->hour(), qobject_cast<Sigmod::Time*>(modified())->minute()));
}

void Sigmodr::TimeUI::apply()
{
    *qobject_cast<Sigmod::Time*>(original()) = *qobject_cast<Sigmod::Time*>(modified());
    emit(changed(false));
}

void Sigmodr::TimeUI::discard()
{
    *qobject_cast<Sigmod::Time*>(modified()) = *qobject_cast<Sigmod::Time*>(original());
    setGui();
    emit(changed(false));
}

void Sigmodr::TimeUI::on_varName_textChanged(const QString& name)
{
    const int cursor = varName->cursorPosition();
    qobject_cast<Sigmod::Time*>(modified())->setName(name);
    varName->setCursorPosition(cursor);
}

void Sigmodr::TimeUI::on_varTime_timeChanged(const QTime& time)
{
    qobject_cast<Sigmod::Time*>(modified())->setHour(time.hour());
    qobject_cast<Sigmod::Time*>(modified())->setMinute(time.minute());
}
