/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "CoinListModel.h"

// Model includes
#include "CoinListObjectModel.h"
#include "GroupModel.h"

// Sigmodr includes
#include "../CoinListUI.h"

// Sigmod includes
#include "../../sigmod/CoinList.h"
#include "../../sigmod/CoinListObject.h"

// KDE includes
#include <KMenu>

Sigmodr::CoinListModel::CoinListModel(BaseModel* parent, Sigmod::CoinList* coinList) :
        GroupObjectModel(parent, coinList)
{
    setupData();
}

Sigmodr::CoinListModel::~CoinListModel()
{
    clearData();
}

QVariant Sigmodr::CoinListModel::data(int role) const
{
    if (role == Qt::DisplayRole)
        return qobject_cast<Sigmod::CoinList*>(m_object)->name();
    else if (role == Sigmodr::BaseModel::XmlRole)
    {
        QDomDocument xml(m_object->className());
        xml.appendChild(m_object->save());
        return xml.toString();
    }
    else if (role == Sigmodr::BaseModel::WidgetRole)
    {
        QWidget* widget = new CoinListUI(qobject_cast<Sigmod::CoinList*>(m_object), NULL);
        return QVariant::fromValue(widget);
    }
    else if (role == Sigmodr::BaseModel::ContextMenuRole)
    {
        KMenu* menu = new KMenu;
        menu->addAction("&Add Object", this, SLOT(addObject()));
        menu->addSeparator();
        menu->addAction("&Delete Coin List", this, SLOT(deleteSelf()));
        return QVariant::fromValue(menu);
    }
    return Sigmodr::GroupObjectModel::data(role);
}

bool Sigmodr::CoinListModel::setData(const QVariant& value, int role)
{
    if (role == Sigmodr::BaseModel::XmlRole)
    {
        QString data = value.toString();
        if (!data.isEmpty())
        {
            QDomDocument xml;
            if (loadFromData(data, &xml))
            {
                if (xml.doctype().name() == m_object->className())
                {
                    clearData();
                    m_object->load(xml.documentElement());
                    setupData();
                    return true;
                }
                else if (xml.doctype().name() == "CoinListObject")
                {
                    addObject(qobject_cast<Sigmod::CoinList*>(m_object)->newObject(xml.documentElement()));
                    return true;
                }
            }
        }
    }
    return false;
}

QString Sigmodr::CoinListModel::types() const
{
    return type().append(";CoinListObject");
}

void Sigmodr::CoinListModel::addObject(Sigmod::Object* object)
{
    if (!object)
        object = qobject_cast<Sigmod::CoinList*>(m_object)->newObject();
    if (object->className() == "CoinListObject")
        addChild(new CoinListObjectModel(this, qobject_cast<Sigmod::CoinListObject*>(object)));
}

void Sigmodr::CoinListModel::deleteObject(BaseModel* model)
{
    const int index = find(model);
    if (0 <= index)
    {
        qobject_cast<Sigmod::CoinList*>(m_object)->deleteObject(index);
        m_objects[index]->deleteLater();
        m_objects.removeAt(index);
        childRowChanged(index);
    }
}

void Sigmodr::CoinListModel::deleteSelf()
{
    qobject_cast<GroupModel*>(m_parent)->deleteObject(this);
}

void Sigmodr::CoinListModel::setupData()
{
    Sigmod::CoinList* coinList = qobject_cast<Sigmod::CoinList*>(m_object);
    for (int i = 0; i < coinList->objectCount(); ++i)
        addChild(new CoinListObjectModel(this, coinList->object(i)));
}
