/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "GlobalScriptGroupModel.h"

// Model includes
#include "GlobalScriptModel.h"

// Sigmod includes
#include "../../sigmod/GlobalScript.h"
#include "../../sigmod/Sigmod.h"

// KDE includes
#include <KMenu>

Sigmodr::GlobalScriptGroupModel::GlobalScriptGroupModel(BaseModel* parent, Sigmod::Sigmod* sigmod) :
        GroupModel(parent, sigmod, "Global Scripts")
{
    for (int i = 0; i < sigmod->globalScriptCount(); ++i)
        addObject(sigmod->globalScript(i));
}

Sigmodr::GlobalScriptGroupModel::~GlobalScriptGroupModel()
{
}

QVariant Sigmodr::GlobalScriptGroupModel::data(const int role) const
{
    if (role == Sigmodr::BaseModel::ContextMenuRole)
    {
        KMenu* menu = new KMenu;
        menu->addAction("&Add Global Script", this, SLOT(addObject()));
        return QVariant::fromValue(menu);
    }
    return Sigmodr::GroupModel::data(role);
}

bool Sigmodr::GlobalScriptGroupModel::setData(const QVariant& value, int role)
{
    if (role == Sigmodr::BaseModel::XmlRole)
    {
        QString data = value.toString();
        if (!data.isEmpty())
        {
            QDomDocument xml;
            if (loadFromData(data, &xml) && (xml.doctype().name() == "GlobalScript"))
            {
                addObject(qobject_cast<Sigmod::Sigmod*>(m_object)->newGlobalScript(xml.documentElement()));
                return true;
            }
        }
    }
    return false;
}

QString Sigmodr::GlobalScriptGroupModel::types() const
{
    return "GlobalScript";
}

void Sigmodr::GlobalScriptGroupModel::addObject(Sigmod::Object* object)
{
    if (!object)
        object = qobject_cast<Sigmod::Sigmod*>(m_object)->newGlobalScript();
    if (object->className() == "GlobalScript")
        addChild(new GlobalScriptModel(this, qobject_cast<Sigmod::GlobalScript*>(object)));
}

void Sigmodr::GlobalScriptGroupModel::deleteObject(BaseModel* model)
{
    const int index = find(model);
    if (0 <= index)
    {
        qobject_cast<Sigmod::Sigmod*>(m_object)->deleteGlobalScript(index);
        m_objects[index]->deleteLater();
        m_objects.removeAt(index);
        childRowChanged(index);
    }
}
