/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SIGMODR_GROUPMODEL
#define SIGMODR_GROUPMODEL

// Model includes
#include "BaseModel.h"
#include "Grouping.h"

// Qt includes
#include <QtCore/QList>

// Forward declarations
namespace Sigmod
{
class Object;
}
namespace Sigmodr
{
class BaseModel;

class GroupModel : public BaseModel, public Grouping
{
    Q_OBJECT
    
    public:
        GroupModel(BaseModel* parent, Sigmod::Object* object, const QString& name = "");
        virtual ~GroupModel();
        
        QVariant data(int role = Qt::DisplayRole) const;
        int rowCount() const;
        
        Qt::ItemFlags flags() const;
        virtual bool setData(const QVariant& value, int role = Qt::EditRole) = 0;
        
        BaseModel* childItem(const int row);
        
        Qt::DropActions supportedDragActions() const;
        Qt::DropActions supportedDropActions() const;
        
        virtual QString types() const = 0;
    public slots:
        void addChild(BaseModel* model);
        
        virtual void addObject(Sigmod::Object* object = NULL) = 0;
        virtual void deleteObject(BaseModel* model) = 0;
    protected:
        int findChild(BaseModel* model) const;
};
}

#endif
