/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "GroupObjectModel.h"

Sigmodr::GroupObjectModel::GroupObjectModel(BaseModel* parent, Sigmod::Object* object) :
        BaseObjectModel(parent, object),
        Grouping()
{
}

Sigmodr::GroupObjectModel::~GroupObjectModel()
{
}

QVariant Sigmodr::GroupObjectModel::data(int role) const
{
    return Sigmodr::BaseObjectModel::data(role);
}

int Sigmodr::GroupObjectModel::rowCount() const
{
    return m_objects.size();
}

Sigmodr::BaseModel* Sigmodr::GroupObjectModel::childItem(const int row)
{
    if (row < m_objects.size())
        return m_objects[row];
    return NULL;
}

void Sigmodr::GroupObjectModel::addChild(BaseModel* model)
{
    connect(model, SIGNAL(rowChanged(int)), this, SLOT(childRowChanged(int)));
    connect(model, SIGNAL(rowsChanged(QList<int>)), this, SLOT(childRowsChanged(QList<int>)));
    m_objects.append(model);
    emit(rowChanged(m_objects.size() - 1));
}

int Sigmodr::GroupObjectModel::findChild(BaseModel* model) const
{
    return find(model);
}
