/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "MapEffectGroupModel.h"

// Model includes
#include "MapEffectModel.h"

// Map includes
#include "../../sigmod/Map.h"
#include "../../sigmod/MapEffect.h"

// KDE includes
#include <KMenu>

Sigmodr::MapEffectGroupModel::MapEffectGroupModel(BaseModel* parent, Sigmod::Map* map) :
        GroupModel(parent, map, "Effects")
{
    for (int i = 0; i < map->effectCount(); ++i)
        addObject(map->effect(i));
}

Sigmodr::MapEffectGroupModel::~MapEffectGroupModel()
{
}

QVariant Sigmodr::MapEffectGroupModel::data(const int role) const
{
    if (role == Sigmodr::BaseModel::ContextMenuRole)
    {
        KMenu* menu = new KMenu;
        menu->addAction("&Add Effect", this, SLOT(addObject()));
        return QVariant::fromValue(menu);
    }
    return Sigmodr::GroupModel::data(role);
}

bool Sigmodr::MapEffectGroupModel::setData(const QVariant& value, int role)
{
    if (role == Sigmodr::BaseModel::XmlRole)
    {
        QString data = value.toString();
        if (!data.isEmpty())
        {
            QDomDocument xml;
            if (loadFromData(data, &xml) && (xml.doctype().name() == "MapEffect"))
            {
                addObject(qobject_cast<Sigmod::Map*>(m_object)->newEffect(xml.documentElement()));
                return true;
            }
        }
    }
    return false;
}

QString Sigmodr::MapEffectGroupModel::types() const
{
    return "MapEffect";
}

void Sigmodr::MapEffectGroupModel::addObject(Sigmod::Object* object)
{
    if (!object)
        object = qobject_cast<Sigmod::Map*>(m_object)->newEffect();
    if (object->className() == "MapEffect")
        addChild(new MapEffectModel(this, qobject_cast<Sigmod::MapEffect*>(object)));
}

void Sigmodr::MapEffectGroupModel::deleteObject(BaseModel* model)
{
    const int index = find(model);
    if (0 <= index)
    {
        qobject_cast<Sigmod::Map*>(m_object)->deleteEffect(index);
        m_objects[index]->deleteLater();
        m_objects.removeAt(index);
        childRowChanged(index);
    }
}
