/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "MapModel.h"

// Model includes
#include "MapEffectGroupModel.h"
#include "MapTrainerGroupModel.h"
#include "MapWarpGroupModel.h"
#include "MapWildListGroupModel.h"

// Sigmodr includes
#include "../MapUI.h"

// Sigmod includes
#include "../../sigmod/Map.h"

// KDE includes
#include <KMenu>

Sigmodr::MapModel::MapModel(BaseModel* parent, Sigmod::Map* map) :
        GroupObjectModel(parent, map)
{
    setupData();
}

Sigmodr::MapModel::~MapModel()
{
    clearData();
}

QVariant Sigmodr::MapModel::data(int role) const
{
    if (role == Qt::DisplayRole)
        return qobject_cast<Sigmod::Map*>(m_object)->name();
    else if (role == Sigmodr::BaseModel::XmlRole)
    {
        QDomDocument xml(m_object->className());
        xml.appendChild(m_object->save());
        return xml.toString();
    }
    else if (role == Sigmodr::BaseModel::WidgetRole)
    {
        QWidget* widget = new MapUI(qobject_cast<Sigmod::Map*>(m_object), NULL);
        return QVariant::fromValue(widget);
    }
    else if (role == Sigmodr::BaseModel::ContextMenuRole)
    {
        KMenu* menu = new KMenu;
        menu->addAction("&Delete Map", this, SLOT(deleteSelf()));
        return QVariant::fromValue(menu);
    }
    return Sigmodr::GroupObjectModel::data(role);
}

bool Sigmodr::MapModel::setData(const QVariant& value, int role)
{
    if (role == Sigmodr::BaseModel::XmlRole)
    {
        QString data = value.toString();
        if (!data.isEmpty())
        {
            QDomDocument xml;
            if (loadFromData(data, &xml))
            {
                if (xml.doctype().name() == m_object->className())
                {
                    clearData();
                    m_object->load(xml.documentElement());
                    setupData();
                    return true;
                }
                foreach (BaseModel* model, m_objects)
                {
                    GroupModel* group = qobject_cast<GroupModel*>(model);
                    if (group && group->setData(value, role))
                        return true;
                }
            }
        }
    }
    return false;
}

QString Sigmodr::MapModel::types() const
{
    return type().append(";MapEffect;MapTrainer;MapWarp;MapWildList");
}

void Sigmodr::MapModel::addObject(Sigmod::Object* /*object*/)
{
}

void Sigmodr::MapModel::deleteObject(BaseModel* /*model*/)
{
}

void Sigmodr::MapModel::deleteSelf()
{
    qobject_cast<GroupModel*>(m_parent)->deleteObject(this);
}

void Sigmodr::MapModel::setupData()
{
    Sigmod::Map* map = qobject_cast<Sigmod::Map*>(m_object);
    addChild(new MapEffectGroupModel(this, map));
    addChild(new MapTrainerGroupModel(this, map));
    addChild(new MapWarpGroupModel(this, map));
    addChild(new MapWildListGroupModel(this, map));
}
