/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "SigmodModel.h"

// Model includes
#include "AbilityGroupModel.h"
#include "AuthorGroupModel.h"
#include "BadgeGroupModel.h"
#include "CoinListGroupModel.h"
#include "EggGroupGroupModel.h"
#include "GlobalScriptGroupModel.h"
#include "ItemGroupModel.h"
#include "ItemTypeGroupModel.h"
#include "MapGroupModel.h"
#include "MoveGroupModel.h"
#include "NatureGroupModel.h"
#include "RulesModel.h"
#include "SkinGroupModel.h"
#include "SoundGroupModel.h"
#include "SpeciesGroupModel.h"
#include "SpriteGroupModel.h"
#include "StatusGroupModel.h"
#include "StoreGroupModel.h"
#include "TileGroupModel.h"
#include "TimeGroupModel.h"
#include "TrainerGroupModel.h"
#include "TypeGroupModel.h"
#include "WeatherGroupModel.h"

// Sigmodr includes
#include "../SigmodUI.h"

// Sigmod includes
#include "../../sigmod/Sigmod.h"

// KDE includes
#include <KMenu>

Sigmodr::SigmodModel::SigmodModel(BaseModel* parent, Sigmod::Sigmod* sigmod) :
        GroupObjectModel(parent, sigmod)
{
    setupData();
}

Sigmodr::SigmodModel::~SigmodModel()
{
    clearData();
}

QVariant Sigmodr::SigmodModel::data(int role) const
{
    if (role == Qt::DisplayRole)
        return qobject_cast<Sigmod::Sigmod*>(m_object)->title();
    else if (role == Sigmodr::BaseModel::XmlRole)
    {
        QDomDocument xml(m_object->className());
        xml.appendChild(m_object->save());
        return xml.toString();
    }
    else if (role == Sigmodr::BaseModel::WidgetRole)
    {
        QWidget* widget = new SigmodUI(qobject_cast<Sigmod::Sigmod*>(m_object), NULL);
        return QVariant::fromValue(widget);
    }
    else if (role == Sigmodr::BaseModel::ContextMenuRole)
    {
        KMenu* menu = new KMenu;
        return QVariant::fromValue(menu);
    }
    return Sigmodr::GroupObjectModel::data(role);
}

bool Sigmodr::SigmodModel::setData(const QVariant& value, int role)
{
    if (role == Sigmodr::BaseModel::XmlRole)
    {
        QString data = value.toString();
        if (!data.isEmpty())
        {
            QDomDocument xml;
            if (loadFromData(data, &xml))
            {
                if (xml.doctype().name() == m_object->className())
                {
                    clearData();
                    m_object->load(xml.documentElement());
                    setupData();
                    return true;
                }
                foreach (BaseModel* model, m_objects)
                {
                    GroupModel* group = qobject_cast<GroupModel*>(model);
                    if (group && group->setData(value, role))
                        return true;
                }
            }
        }
    }
    return false;
}

QString Sigmodr::SigmodModel::types() const
{
    return type().append(";Rules;Ability;Author;Badge;CoinList;EggGroup;GlobalScript;Item;ItemType;Map;Move;Nature;Skin;Sound;Species;Sprite;Status;Store;Tile;Time;Trainer;Type;Weather");
}

void Sigmodr::SigmodModel::addObject(Sigmod::Object* /*object*/)
{
}

void Sigmodr::SigmodModel::deleteObject(BaseModel* /*model*/)
{
}

void Sigmodr::SigmodModel::deleteSelf()
{
}

void Sigmodr::SigmodModel::setupData()
{
    Sigmod::Sigmod* sigmod = qobject_cast<Sigmod::Sigmod*>(m_object);
    addChild(new RulesModel(this, sigmod->rules()));
    addChild(new AbilityGroupModel(this, sigmod));
    addChild(new AuthorGroupModel(this, sigmod));
    addChild(new BadgeGroupModel(this, sigmod));
    addChild(new CoinListGroupModel(this, sigmod));
    addChild(new EggGroupGroupModel(this, sigmod));
    addChild(new GlobalScriptGroupModel(this, sigmod));
    addChild(new ItemGroupModel(this, sigmod));
    addChild(new ItemTypeGroupModel(this, sigmod));
    addChild(new MapGroupModel(this, sigmod));
    addChild(new MoveGroupModel(this, sigmod));
    addChild(new NatureGroupModel(this, sigmod));
    addChild(new SkinGroupModel(this, sigmod));
    addChild(new SoundGroupModel(this, sigmod));
    addChild(new SpeciesGroupModel(this, sigmod));
    addChild(new SpriteGroupModel(this, sigmod));
    addChild(new StatusGroupModel(this, sigmod));
    addChild(new StoreGroupModel(this, sigmod));
    addChild(new TileGroupModel(this, sigmod));
    addChild(new TimeGroupModel(this, sigmod));
    addChild(new TrainerGroupModel(this, sigmod));
    addChild(new TypeGroupModel(this, sigmod));
    addChild(new WeatherGroupModel(this, sigmod));
}
