/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "SpeciesAbilityGroupModel.h"

// Model includes
#include "SpeciesAbilityModel.h"

// Sigmod includes
#include "../../sigmod/Species.h"
#include "../../sigmod/SpeciesAbility.h"

// KDE includes
#include <KMenu>

Sigmodr::SpeciesAbilityGroupModel::SpeciesAbilityGroupModel(BaseModel* parent, Sigmod::Species* species) :
        GroupModel(parent, species, "Abilities")
{
    for (int i = 0; i < species->abilityCount(); ++i)
        addObject(species->ability(i));
}

Sigmodr::SpeciesAbilityGroupModel::~SpeciesAbilityGroupModel()
{
}

QVariant Sigmodr::SpeciesAbilityGroupModel::data(const int role) const
{
    if (role == Sigmodr::BaseModel::ContextMenuRole)
    {
        KMenu* menu = new KMenu;
        menu->addAction("&Add Ability", this, SLOT(addObject()));
        return QVariant::fromValue(menu);
    }
    return Sigmodr::GroupModel::data(role);
}

bool Sigmodr::SpeciesAbilityGroupModel::setData(const QVariant& value, int role)
{
    if (role == Sigmodr::BaseModel::XmlRole)
    {
        QString data = value.toString();
        if (!data.isEmpty())
        {
            QDomDocument xml;
            if (loadFromData(data, &xml) && (xml.doctype().name() == "SpeciesAbility"))
            {
                addObject(qobject_cast<Sigmod::Species*>(m_object)->newAbility(xml.documentElement()));
                return true;
            }
        }
    }
    return false;
}

QString Sigmodr::SpeciesAbilityGroupModel::types() const
{
    return "SpeciesAbility";
}

void Sigmodr::SpeciesAbilityGroupModel::addObject(Sigmod::Object* object)
{
    if (!object)
        object = qobject_cast<Sigmod::Species*>(m_object)->newAbility();
    if (object->className() == "SpeciesAbility")
        addChild(new SpeciesAbilityModel(this, qobject_cast<Sigmod::SpeciesAbility*>(object)));
}

void Sigmodr::SpeciesAbilityGroupModel::deleteObject(BaseModel* model)
{
    const int index = find(model);
    if (0 <= index)
    {
        qobject_cast<Sigmod::Species*>(m_object)->deleteAbility(index);
        m_objects[index]->deleteLater();
        m_objects.removeAt(index);
        childRowChanged(index);
    }
}
