/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "SpeciesItemModel.h"

// Model includes
#include "GroupModel.h"

// Sigmodr includes
#include "../SpeciesItemUI.h"

// Sigmod includes
#include "../../sigmod/Item.h"
#include "../../sigmod/Sigmod.h"
#include "../../sigmod/Species.h"
#include "../../sigmod/SpeciesItem.h"

// KDE includes
#include <KMenu>

Sigmodr::SpeciesItemModel::SpeciesItemModel(BaseModel* parent, Sigmod::SpeciesItem* item) :
        ObjectModel(parent, item)
{
}

Sigmodr::SpeciesItemModel::~SpeciesItemModel()
{
}

QVariant Sigmodr::SpeciesItemModel::data(int role) const
{
    if (role == Qt::DisplayRole)
    {
        const int index = qobject_cast<const Sigmod::Sigmod*>(m_object->sigmod())->itemIndex(qobject_cast<Sigmod::SpeciesItem*>(m_object)->item());
        if (index != INT_MAX)
            return qobject_cast<const Sigmod::Sigmod*>(m_object->sigmod())->item(index)->name();
        return "";
    }
    else if (role == Sigmodr::BaseModel::XmlRole)
    {
        QDomDocument xml(m_object->className());
        xml.appendChild(m_object->save());
        return xml.toString();
    }
    else if (role == Sigmodr::BaseModel::WidgetRole)
    {
        QWidget* widget = new SpeciesItemUI(qobject_cast<Sigmod::SpeciesItem*>(m_object), NULL);
        return QVariant::fromValue(widget);
    }
    else if (role == Sigmodr::BaseModel::ContextMenuRole)
    {
        KMenu* menu = new KMenu;
        menu->addAction("&Delete Item", this, SLOT(deleteSelf()));
        return QVariant::fromValue(menu);
    }
    return Sigmodr::ObjectModel::data(role);
}

void Sigmodr::SpeciesItemModel::deleteSelf()
{
    qobject_cast<GroupModel*>(m_parent)->deleteObject(this);
}
