/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// header include
#include "AbilityWrapper.h"

// Sigscript includes
#include "SigmodWrapper.h"

Sigscript::AbilityWrapper* Sigscript::AbilityWrapper::create(const Sigmod::Ability* ability, SigmodWrapper* parent)
{
    if (!m_instances.contains(Signature(parent, ability->id())))
        m_instances[Signature(parent, ability->id())] = new AbilityWrapper(ability, parent);
    return qobject_cast<AbilityWrapper*>(m_instances[Signature(parent, ability->id())]);
}

Sigscript::AbilityWrapper::AbilityWrapper(const Sigmod::Ability* ability, SigmodWrapper* parent) :
        ObjectWrapper(ability, parent),
        m_ability(ability)
{
}

QString Sigscript::AbilityWrapper::name() const
{
    return m_ability->name();
}

int Sigscript::AbilityWrapper::priority() const
{
    if (hasValueOfType<int>("priority"))
        return valueOfType<int>("priority");
    return m_ability->priority();
}

QString Sigscript::AbilityWrapper::description() const
{
    return m_ability->description();
}

Sigmod::Script Sigscript::AbilityWrapper::battleScript() const
{
    return m_ability->battleScript();
}

Sigmod::Script Sigscript::AbilityWrapper::worldScript() const
{
    return m_ability->worldScript();
}

Sigmod::Script Sigscript::AbilityWrapper::priorityScript() const
{
    return m_ability->priorityScript();
}
