/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "BadgeWrapper.h"

// Sigscript includes
#include "SigmodWrapper.h"

Sigscript::BadgeWrapper* Sigscript::BadgeWrapper::create(const Sigmod::Badge* badge, SigmodWrapper* parent)
{
    if (!m_instances.contains(Signature(parent, badge->id())))
        m_instances[Signature(parent, badge->id())] = new BadgeWrapper(badge, parent);
    return qobject_cast<BadgeWrapper*>(m_instances[Signature(parent, badge->id())]);
}

Sigscript::BadgeWrapper::BadgeWrapper(const Sigmod::Badge* badge, SigmodWrapper* parent) :
        ObjectWrapper(badge, parent),
        m_badge(badge)
{
}

QString Sigscript::BadgeWrapper::name() const
{
    return m_badge->name();
}

Sigscript::SpriteWrapper* Sigscript::BadgeWrapper::face()
{
    return sigmod()->sprite(m_badge->face());
}

Sigscript::SpriteWrapper* Sigscript::BadgeWrapper::badge()
{
    return sigmod()->sprite(m_badge->badge());
}

int Sigscript::BadgeWrapper::obey() const
{
    return m_badge->obey();
}

Sigmod::Fraction Sigscript::BadgeWrapper::stat(const Sigmod::Stat stat) const
{
    return m_badge->stat(stat);
}
