/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "CoinListObjectWrapper.h"

// Sigscript includes
#include "CoinListWrapper.h"
#include "SigmodWrapper.h"

Sigscript::CoinListObjectWrapper* Sigscript::CoinListObjectWrapper::create(const Sigmod::CoinListObject* object, CoinListWrapper* parent)
{
    if (!m_instances.contains(Signature(parent, object->id())))
        m_instances[Signature(parent, object->id())] = new CoinListObjectWrapper(object, parent);
    return qobject_cast<CoinListObjectWrapper*>(m_instances[Signature(parent, object->id())]);
}

Sigscript::CoinListObjectWrapper::CoinListObjectWrapper(const Sigmod::CoinListObject* object, CoinListWrapper* parent) :
        ObjectWrapper(object, parent),
        m_object(object)
{
}

Sigmod::CoinListObject::Type Sigscript::CoinListObjectWrapper::type(const QString& name) const
{
    if (name == "Item")
        return Sigmod::CoinListObject::Item;
    else if (name == "Species")
        return Sigmod::CoinListObject::Species;
    return QVariant(-1).value<Sigmod::CoinListObject::Type>();
}

Sigmod::CoinListObject::Type Sigscript::CoinListObjectWrapper::type() const
{
    return m_object->type();
}

Sigscript::ItemWrapper* Sigscript::CoinListObjectWrapper::itemObject()
{
    if (m_object->type() == Sigmod::CoinListObject::Item)
        return sigmod()->item(m_object->object());
    return NULL;
}

Sigscript::SpeciesWrapper* Sigscript::CoinListObjectWrapper::speciesObject()
{
    if (m_object->type() == Sigmod::CoinListObject::Species)
        return sigmod()->species(m_object->object());
    return NULL;
}

int Sigscript::CoinListObjectWrapper::amount() const
{
    if (hasValueOfType<int>("amount"))
        return valueOfType<int>("amount");
    return m_object->amount();
}

int Sigscript::CoinListObjectWrapper::cost() const
{
    if (hasValueOfType<int>("cost"))
        return valueOfType<int>("cost");
    return m_object->cost();
}
