/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "MapEffectWrapper.h"

// Sigscript includes
#include "MapWrapper.h"
#include "SigmodWrapper.h"

Sigscript::MapEffectWrapper* Sigscript::MapEffectWrapper::create(const Sigmod::MapEffect* effect, MapWrapper* parent)
{
    if (!m_instances.contains(Signature(parent, effect->id())))
        m_instances[Signature(parent, effect->id())] = new MapEffectWrapper(effect, parent);
    return qobject_cast<MapEffectWrapper*>(m_instances[Signature(parent, effect->id())]);
}

Sigscript::MapEffectWrapper::MapEffectWrapper(const Sigmod::MapEffect* effect, MapWrapper* parent) :
        ObjectWrapper(effect, parent),
        m_effect(effect)
{
}

QString Sigscript::MapEffectWrapper::name() const
{
    return m_effect->name();
}

QPoint Sigscript::MapEffectWrapper::coordinate() const
{
    if (hasValueOfType<QPoint>("coordinate"))
        return valueOfType<QPoint>("coordinate");
    return m_effect->coordinate();
}

Sigscript::SkinWrapper* Sigscript::MapEffectWrapper::skin()
{
    return sigmod()->skin(m_effect->skin());
}

bool Sigscript::MapEffectWrapper::isGhost() const
{
    if (hasValueOfType<bool>("ghost"))
        return valueOfType<bool>("ghost");
    return m_effect->isGhost();
}

Sigmod::Script Sigscript::MapEffectWrapper::script() const
{
    return m_effect->script();
}
