/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "MapTrainerTeamMemberWrapper.h"

// Sigscript includes
#include "MapTrainerWrapper.h"
#include "SigmodWrapper.h"

Sigscript::MapTrainerTeamMemberWrapper* Sigscript::MapTrainerTeamMemberWrapper::create(const Sigmod::MapTrainerTeamMember* teamMember, MapTrainerWrapper* parent)
{
    if (!m_instances.contains(Signature(parent, teamMember->id())))
        m_instances[Signature(parent, teamMember->id())] = new MapTrainerTeamMemberWrapper(teamMember, parent);
    return qobject_cast<MapTrainerTeamMemberWrapper*>(m_instances[Signature(parent, teamMember->id())]);
}

Sigscript::MapTrainerTeamMemberWrapper::MapTrainerTeamMemberWrapper(const Sigmod::MapTrainerTeamMember* teamMember, MapTrainerWrapper* parent) :
        ObjectWrapper(teamMember, parent),
        m_teamMember(teamMember)
{
}

Sigscript::SpeciesWrapper* Sigscript::MapTrainerTeamMemberWrapper::species()
{
    return sigmod()->species(m_teamMember->species());
}

int Sigscript::MapTrainerTeamMemberWrapper::level() const
{
    if (hasValueOfType<int>("level"))
        return valueOfType<int>("level");
    return m_teamMember->level();
}

QList<Sigscript::AbilityWrapper*> Sigscript::MapTrainerTeamMemberWrapper::abilities()
{
    QList<int> abilityIds = m_teamMember->abilities();
    QList<AbilityWrapper*> abilities;
    foreach (int id, abilityIds)
        abilities.append(sigmod()->ability(id));
    return abilities;
}

QList<Sigscript::ItemWrapper*> Sigscript::MapTrainerTeamMemberWrapper::items()
{
    QList<int> itemIds = m_teamMember->items();
    QList<ItemWrapper*> items;
    foreach (int id, itemIds)
        items.append(sigmod()->item(id));
    return items;
}

QList<Sigscript::MoveWrapper*> Sigscript::MapTrainerTeamMemberWrapper::moves()
{
    QList<int> moveIds = m_teamMember->moves();
    QList<MoveWrapper*> moves;
    foreach (int id, moveIds)
        moves.append(sigmod()->move(id));
    return moves;
}

QList<Sigscript::NatureWrapper*> Sigscript::MapTrainerTeamMemberWrapper::natures()
{
    QList<int> natureIds = m_teamMember->natures();
    QList<NatureWrapper*> natures;
    foreach (int id, natureIds)
        natures.append(sigmod()->nature(id));
    return natures;
}
