/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "MapTrainerWrapper.h"

// Sigscript includes
#include "MapWrapper.h"
#include "MapTrainerTeamMemberWrapper.h"
#include "SigmodWrapper.h"

Sigscript::MapTrainerWrapper* Sigscript::MapTrainerWrapper::create(const Sigmod::MapTrainer* trainer, MapWrapper* parent)
{
    if (!m_instances.contains(Signature(parent, trainer->id())))
        m_instances[Signature(parent, trainer->id())] = new MapTrainerWrapper(trainer, parent);
    return qobject_cast<MapTrainerWrapper*>(m_instances[Signature(parent, trainer->id())]);
}

Sigscript::MapTrainerWrapper::MapTrainerWrapper(const Sigmod::MapTrainer* trainer, MapWrapper* parent) :
        ObjectWrapper(trainer, parent),
        m_trainer(trainer)
{
}

QString Sigscript::MapTrainerWrapper::name() const
{
    return m_trainer->name();
}

Sigscript::TrainerWrapper* Sigscript::MapTrainerWrapper::trainerClass()
{
    return sigmod()->trainer(m_trainer->trainerClass());
}

int Sigscript::MapTrainerWrapper::numberFight() const
{
    return m_trainer->numberFight();
}

Sigscript::MapTrainerTeamMemberWrapper* Sigscript::MapTrainerWrapper::leadTeamMember()
{
    return teamMember(m_trainer->leadTeamMember());
}

Sigmod::Script Sigscript::MapTrainerWrapper::script() const
{
    return m_trainer->script();
}

Sigscript::MapTrainerTeamMemberWrapper* Sigscript::MapTrainerWrapper::teamMember(const int index)
{
    return MapTrainerTeamMemberWrapper::create(m_trainer->teamMember(index), this);
}

int Sigscript::MapTrainerWrapper::teamMemberCount() const
{
    return m_trainer->teamMemberCount();
}
