/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "MapWildListWrapper.h"

// Sigscript includes
#include "MapWrapper.h"
#include "MapWildListEncounterWrapper.h"

Sigscript::MapWildListWrapper* Sigscript::MapWildListWrapper::create(const Sigmod::MapWildList* wildList, MapWrapper* parent)
{
    if (!m_instances.contains(Signature(parent, wildList->id())))
        m_instances[Signature(parent, wildList->id())] = new MapWildListWrapper(wildList, parent);
    return qobject_cast<MapWildListWrapper*>(m_instances[Signature(parent, wildList->id())]);
}

Sigscript::MapWildListWrapper::MapWildListWrapper(const Sigmod::MapWildList* wildList, MapWrapper* parent) :
        ObjectWrapper(wildList, parent),
        m_wildList(wildList)
{
}

Sigmod::Hat<Sigscript::MapWildListEncounterWrapper*> Sigscript::MapWildListWrapper::encounterHat()
{
    Sigmod::Hat<MapWildListEncounterWrapper*> hat;
    for (int i = 0; i < encounterCount(); ++i)
        hat.add(encounter(i), encounter(i)->weight());
    return hat;
}

QString Sigscript::MapWildListWrapper::name() const
{
    return m_wildList->name();
}

Sigscript::MapWildListEncounterWrapper* Sigscript::MapWildListWrapper::encounter(const int index)
{
    return MapWildListEncounterWrapper::create(m_wildList->encounter(index), this);
}

int Sigscript::MapWildListWrapper::encounterCount() const
{
    return m_wildList->encounterCount();
}
