/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "MoveWrapper.h"

// Sigscript includes
#include "SigmodWrapper.h"

Sigscript::MoveWrapper* Sigscript::MoveWrapper::create(const Sigmod::Move* move, SigmodWrapper* parent)
{
    if (!m_instances.contains(Signature(parent, move->id())))
        m_instances[Signature(parent, move->id())] = new MoveWrapper(move, parent);
    return qobject_cast<MoveWrapper*>(m_instances[Signature(parent, move->id())]);
}

Sigscript::MoveWrapper::MoveWrapper(const Sigmod::Move* move, SigmodWrapper* parent) :
        ObjectWrapper(move, parent),
        m_move(move)
{
}

QString Sigscript::MoveWrapper::name() const
{
    return m_move->name();
}

Sigmod::Fraction Sigscript::MoveWrapper::accuracy() const
{
    if (hasValueOfType<Sigmod::Fraction>("accuracy"))
        return valueOfType<Sigmod::Fraction>("accuracy");
    return m_move->accuracy();
}

int Sigscript::MoveWrapper::power() const
{
    if (hasValueOfType<int>("power"))
        return valueOfType<int>("power");
    return m_move->power();
}

Sigscript::TypeWrapper* Sigscript::MoveWrapper::type()
{
    return sigmod()->type(m_move->type());
}

bool Sigscript::MoveWrapper::special() const
{
    return m_move->special();
}

int Sigscript::MoveWrapper::powerPoints() const
{
    return m_move->powerPoints();
}

int Sigscript::MoveWrapper::priority() const
{
    if (hasValueOfType<int>("priority"))
        return valueOfType<int>("priority");
    return m_move->priority();
}

QString Sigscript::MoveWrapper::description() const
{
    return m_move->description();
}

Sigmod::Script Sigscript::MoveWrapper::battleScript() const
{
    return m_move->battleScript();
}

Sigmod::Script Sigscript::MoveWrapper::worldScript() const
{
    return m_move->worldScript();
}

Sigmod::Script Sigscript::MoveWrapper::priorityScript() const
{
    return m_move->priorityScript();
}
