/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "RulesWrapper.h"

// Sigscript includes
#include "SigmodWrapper.h"

Sigscript::RulesWrapper* Sigscript::RulesWrapper::create(const Sigmod::Rules* rules, SigmodWrapper* parent)
{
    if (!m_instances.contains(Signature(parent, rules->id())))
        m_instances[Signature(parent, rules->id())] = new RulesWrapper(rules, parent);
    return qobject_cast<RulesWrapper*>(m_instances[Signature(parent, rules->id())]);
}

Sigscript::RulesWrapper::RulesWrapper(const Sigmod::Rules* rules, SigmodWrapper* parent) :
        ObjectWrapper(rules, parent),
        m_rules(rules)
{
}

bool Sigscript::RulesWrapper::genderAllowed() const
{
    return m_rules->genderAllowed();
}

bool Sigscript::RulesWrapper::breedingAllowed() const
{
    return m_rules->breedingAllowed();
}

bool Sigscript::RulesWrapper::criticalDomains() const
{
    return m_rules->criticalDomains();
}

bool Sigscript::RulesWrapper::useTurns() const
{
    return m_rules->useTurns();
}

int Sigscript::RulesWrapper::numBoxes() const
{
    if (hasValueOfType<int>("numBoxes"))
        return valueOfType<int>("numBoxes");
    return m_rules->numBoxes();
}

int Sigscript::RulesWrapper::boxSize() const
{
    if (hasValueOfType<int>("boxSize"))
        return valueOfType<int>("boxSize");
    return m_rules->boxSize();
}

int Sigscript::RulesWrapper::maxParty() const
{
    if (hasValueOfType<int>("maxParty"))
        return valueOfType<int>("maxParty");
    return m_rules->maxParty();
}

int Sigscript::RulesWrapper::maxFight() const
{
    if (hasValueOfType<int>("maxFight"))
        return valueOfType<int>("maxFight");
    return m_rules->maxFight();
}

int Sigscript::RulesWrapper::maxPlayers() const
{
    if (hasValueOfType<int>("maxFight"))
        return valueOfType<int>("maxFight");
    return m_rules->maxPlayers();
}

int Sigscript::RulesWrapper::maxHeldItems() const
{
    if (hasValueOfType<int>("maxHeldItems"))
        return valueOfType<int>("maxHeldItems");
    return m_rules->maxHeldItems();
}

int Sigscript::RulesWrapper::maxAbilities() const
{
    return m_rules->maxAbilities();
}

int Sigscript::RulesWrapper::maxNatures() const
{
    return m_rules->maxNatures();
}

int Sigscript::RulesWrapper::maxMoves() const
{
    if (hasValueOfType<int>("maxMoves"))
        return valueOfType<int>("maxMoves");
    return m_rules->maxMoves();
}

int Sigscript::RulesWrapper::maxLevel() const
{
    if (hasValueOfType<int>("maxLevel"))
        return valueOfType<int>("maxLevel");
    return m_rules->maxLevel();
}

int Sigscript::RulesWrapper::maxStages() const
{
    if (hasValueOfType<int>("maxStages"))
        return valueOfType<int>("maxStages");
    return m_rules->maxStages();
}

int Sigscript::RulesWrapper::maxMoney() const
{
    if (hasValueOfType<int>("maxMoney"))
        return valueOfType<int>("maxMoney");
    return m_rules->maxMoney();
}

bool Sigscript::RulesWrapper::hardCash() const
{
    return m_rules->hardCash();
}

bool Sigscript::RulesWrapper::allowSwitchStyle() const
{
    if (hasValueOfType<bool>("allowSwitchStyle"))
        return valueOfType<bool>("allowSwitchStyle");
    return m_rules->allowSwitchStyle();
}

bool Sigscript::RulesWrapper::specialSplit() const
{
    return m_rules->specialSplit();
}

bool Sigscript::RulesWrapper::specialDVSplit() const
{
    return m_rules->specialDVSplit();
}

bool Sigscript::RulesWrapper::effortValuesAllowed() const
{
    return m_rules->effortValuesAllowed();
}

int Sigscript::RulesWrapper::maxTotalEV() const
{
    if (hasValueOfType<int>("maxTotalEV"))
        return valueOfType<int>("maxTotalEV");
    return m_rules->maxTotalEV();
}

int Sigscript::RulesWrapper::maxEVPerStat() const
{
    if (hasValueOfType<int>("maxEVPerStat"))
        return valueOfType<int>("maxEVPerStat");
    return m_rules->maxEVPerStat();
}
