/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "TileWrapper.h"

// Sigscript includes
#include "SigmodWrapper.h"
#include "SpriteWrapper.h"

Sigscript::TileWrapper* Sigscript::TileWrapper::create(const Sigmod::Tile* tile, SigmodWrapper* parent)
{
    if (!m_instances.contains(Signature(parent, tile->id())))
        m_instances[Signature(parent, tile->id())] = new TileWrapper(tile, parent);
    return qobject_cast<TileWrapper*>(m_instances[Signature(parent, tile->id())]);
}

Sigscript::TileWrapper::TileWrapper(const Sigmod::Tile* tile, SigmodWrapper* parent) :
        ObjectWrapper(tile, parent),
        m_tile(tile)
{
}

QString Sigscript::TileWrapper::name() const
{
    return m_tile->name();
}

Sigscript::SpriteWrapper* Sigscript::TileWrapper::sprite()
{
    if (hasValueOfType<QString>("sprite"))
    {
        SpriteWrapper* sprite = sigmod()->sprite(valueOfType<QString>("sprite"));
        if (sprite && sprite->sprite().size() == QSize(64, 64))
            return sprite;
    }
    return sigmod()->sprite(m_tile->sprite());
}

bool Sigscript::TileWrapper::from(const Sigmod::Direction direction) const
{
    if (hasValueOfType<bool>(QString("direction-%1").arg(direction)))
        return valueOfType<bool>(QString("direction-%1").arg(direction));
    return m_tile->from(direction);
}

Sigmod::Script Sigscript::TileWrapper::script() const
{
    return m_tile->script();
}
