/*
 * Copyright 2008 Ben Boeckel <MathStuf@gmail.com>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Header include
#include "TrainerWrapper.h"

// Sigscript includes
#include "SigmodWrapper.h"

Sigscript::TrainerWrapper* Sigscript::TrainerWrapper::create(const Sigmod::Trainer* trainer, SigmodWrapper* parent)
{
    if (!m_instances.contains(Signature(parent, trainer->id())))
        m_instances[Signature(parent, trainer->id())] = new TrainerWrapper(trainer, parent);
    return qobject_cast<TrainerWrapper*>(m_instances[Signature(parent, trainer->id())]);
}

Sigscript::TrainerWrapper::TrainerWrapper(const Sigmod::Trainer* trainer, SigmodWrapper* parent) :
        ObjectWrapper(trainer, parent),
        m_trainer(trainer)
{
}

Sigmod::Trainer::Intelligence Sigscript::TrainerWrapper::intelligence(const QString& name) const
{
    if (name == "Ignorant")
        return Sigmod::Trainer::Ignorant;
    else if (name == "Determine")
        return Sigmod::Trainer::Determine;
    else if (name == "Remember")
        return Sigmod::Trainer::Remember;
    else if (name == "Cheating")
        return Sigmod::Trainer::Cheating;
    return QVariant(-1).value<Sigmod::Trainer::Intelligence>();
}

QString Sigscript::TrainerWrapper::TrainerWrapper::name() const
{
    return m_trainer->name();
}

int Sigscript::TrainerWrapper::TrainerWrapper::moneyFactor() const
{
    if (hasValueOfType<int>("moneyFactor"))
        return valueOfType<int>("moneyFactor");
    return m_trainer->moneyFactor();
}

Sigscript::SkinWrapper* Sigscript::TrainerWrapper::TrainerWrapper::skin()
{
    return sigmod()->skin(m_trainer->skin());
}

int Sigscript::TrainerWrapper::TrainerWrapper::depth() const
{
    if (hasValueOfType<int>("depth"))
        return valueOfType<int>("depth");
    return m_trainer->depth();
}

Sigmod::Trainer::Intelligence Sigscript::TrainerWrapper::TrainerWrapper::teamIntel() const
{
    return m_trainer->teamIntel();
}

Sigmod::Trainer::Intelligence Sigscript::TrainerWrapper::TrainerWrapper::moveIntel() const
{
    return m_trainer->moveIntel();
}

Sigmod::Trainer::Intelligence Sigscript::TrainerWrapper::TrainerWrapper::itemIntel() const
{
    return m_trainer->itemIntel();
}

Sigmod::Trainer::Intelligence Sigscript::TrainerWrapper::TrainerWrapper::abilityIntel() const
{
    return m_trainer->abilityIntel();
}

Sigmod::Trainer::Intelligence Sigscript::TrainerWrapper::TrainerWrapper::statIntel() const
{
    return m_trainer->statIntel();
}
